@@ -142,11 +142,11 @@ void ListView::showColumnContextMenu(const QPoint &point)
         }
     }*/
 
-    QAction *actionAuto = NULL;
-    QAction *actionKB = NULL;
-    QAction *actionMB = NULL;
-    QAction *actionGB = NULL;
-    QAction *actionTB = NULL;
+    QAction *actionAuto = nullptr;
+    QAction *actionKB = nullptr;
+    QAction *actionMB = nullptr;
+    QAction *actionGB = nullptr;
+    QAction *actionTB = nullptr;
     if (mColumnTypes[index] == KByte) {
         menu->addSeparator()->setText(i18n("Display Units"));
         QActionGroup *unitsGroup = new QActionGroup(menu);
@@ -283,6 +283,7 @@ ListView::answerReceived(int id, const QList<QByteArray>& answer)
             /* add the new columns */
             mModel.clear();
             QStringList translatedHeaders;
+            translatedHeaders.reserve(headers.count());
             for (uint i = 0; i < headers.count(); i++) {
                 translatedHeaders.append( i18nc("heading from daemon", headers[i].constData()) );
             }
@@ -317,7 +318,7 @@ ListView::answerReceived(int id, const QList<QByteArray>& answer)
                         break;
                       case Percentage:
                         item->setData(records[j].toInt(), Qt::UserRole);
-                        item->setText(records[j] + "%");
+                        item->setText(records[j] + QLatin1Char('%'));
                         break;
                       case Float:
                         item->setData(records[j].toFloat(), Qt::DisplayRole);
@@ -356,7 +357,7 @@ ListView::restoreSettings(QDomElement& element)
     //At this stage, we don't have the heading information, so we cannot setup the headers yet.
     //Save the info, the restore later.
     mHeaderSettings = QByteArray::fromBase64(element.attribute(QStringLiteral("treeViewHeader")).toLatin1());
-    mUnits = (ListView::Units)element.attribute(QStringLiteral("units"), QStringLiteral("0")).toInt();
+    mUnits = static_cast<ListView::Units>(element.attribute(QStringLiteral("units"), QStringLiteral("0")).toInt());
 
 /*    QPalette pal = monitor->palette();
     pal.setColor(QPalette::Link, restoreColor(element, "gridColor",
@@ -410,7 +411,7 @@ ListView::configureSettings()
         applySettings();
 
     delete lvs;
-    lvs = 0;
+    lvs = nullptr;
 }
 
 void
